@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.006_02';
+our $VERSION = '0.006_03';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -1080,10 +1080,6 @@ in C<Module::Build::API>.
  
 =back
 
-=head1 AUTHOR
-
-Joel Berger <joel.a.berger@gmail.com>
-
 =head1 SEE ALSO
 
 =over
@@ -1108,11 +1104,13 @@ L<http://github.com/Perl5-Alien/Alien-Base>
 
 =head1 AUTHOR
 
-Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
+Original author: Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt> and the L<Alien::Base> team
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2014 by Joel Berger
+Copyright (C) 2012-2015 by Joel Berger
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
